==> viewer2d-0.2.2.tgz: package/dev/loadSimpleModel.js <==
export default async function loadSimpleSVGModel(viewer) {
  const model1 = {
    bbox: [-90, 5, 130, 150],
    objects: [
      {
        area: 1,
        type: "eyes",
        geometry: [
          [5, 5, 25, 5, 25, 25, 5, 25, 5, 5],
          [85, 5, 105, 5, 105, 25, 85, 25, 85, 5],
        ],
        zIndex: 0,
      },
      {
        area: 1,
        type: "beak",
        geometry: [[30, 30, 130, 30, 130, 40, 30, 40, 30, 30]],
        zIndex: 2,
      },
    ],
  };

  const model2 = {
    bbox: [-90, 5, 130, 150],
    objects: [
      {
        area: 2,
        type: "head",
        geometry: [[10, 10, 100, 10, 100, 100, 10, 100, 10, 10]],
        zIndex: 1,
      },
      {
        area: 2,
        type: "body",
        geometry: [[10, 100, -90, 100, 10, 150, 100, 150, 100, 100, 10, 100]],
        zIndex: 1,
      },
      {
        area: 1,
        type: "hair",
        geometry: [
          [40, 0, 50, 12],
          [50, 0, 60, 12],
          [60, 0, 70, 12],
        ],
        zIndex: 2,
      },
      {
        area: 2,
        type: "tail",
        geometry: [
          [0, 100, -10, 80, -20, 100, 0, 100],
          [-25, 100, -35, 80, -45, 100, -25, 100],
          [-50, 100, -60, 80, -70, 100, -50, 100],
        ],
      },
    ],
  };

  [...model1.objects, ...model2.objects].forEach(object => {
    if (object.type === "eyes") {
      object.lineWidth = 4;
      object.lineColor = 0x0000ff;
    } else if (object.type === "beak") {
      object.lineWidth = 5;
      object.lineColor = 0xffff00;
    } else if (object.type === "body") {
      object.lineColor = 0x00ff00;
      object.texture = "wall";
    } else if (object.type === "hair") {
      object.lineColor = 0xff0000;
      object.lineWidth = 2;
    } else if (object.type === "tail") {
      object.textureTint = 0x00ffff;
      object.texture = "solid";
      object.lineDash = [5];
    } else if (object.type === "head") {
      object.texture = "diamond";
    }
  });

  viewer.scene.addModel(model1);
  viewer.scene.addModel(model2);
  viewer.camera.fitView(model1.bbox);
}

// async function getBase64Image(src, width = 64, height = width) {
//   const canvas = document.createElement("canvas");
//   canvas.width = width;
//   canvas.height = height;
//   var ctx = canvas.getContext("2d");
//   const image = new Image(width, height);
//   document.body.appendChild(image);
//   const promise = new Promise(res => (image.onload = res));
//   image.src = src;
//   await promise;
//   ctx.drawImage(image, 0, 0);
//   return canvas.toDataURL();
// }

==> viewer2d-0.2.4.tgz: package/dev/loadSimpleModel.js <==
export default async function loadSimpleSVGModel(viewer) {
  const model1 = {
    objects: [
      {
        area: 1,
        type: "eyes",
        geometry: [
          [5, 5, 25, 5, 25, 25, 5, 25, 5, 5],
          [85, 5, 105, 5, 105, 25, 85, 25, 85, 5],
        ],
        zIndex: 0,
      },
      {
        area: 1,
        type: "beak",
        geometry: [[30, 30, 130, 30, 130, 40, 30, 40, 30, 30]],
        zIndex: 2,
      },
    ],
  };

  const model2 = {
    objects: [
      {
        area: 2,
        type: "head",
        geometry: [[10, 10, 100, 10, 100, 100, 10, 100, 10, 10]],
        zIndex: 1,
      },
      {
        area: 2,
        type: "body",
        geometry: [[10, 100, -90, 100, 10, 150, 100, 150, 100, 100, 10, 100]],
        zIndex: 1,
      },
      {
        area: 1,
        type: "hair",
        geometry: [
          [40, 0, 50, 12],
          [50, 0, 60, 12],
          [60, 0, 70, 12],
        ],
        zIndex: 2,
      },
      {
        area: 2,
        type: "tail",
        geometry: [
          [0, 100, -10, 80, -20, 100, 0, 100],
          [-25, 100, -35, 80, -45, 100, -25, 100],
          [-50, 100, -60, 80, -70, 100, -50, 100],
        ],
      },
    ],
  };

  [...model1.objects, ...model2.objects].forEach(object => {
    if (object.type === "eyes") {
      object.lineWidth = 4;
      object.lineColor = 0x0000ff;
    } else if (object.type === "beak") {
      object.lineWidth = 5;
      object.lineColor = 0xffff00;
    } else if (object.type === "body") {
      object.lineColor = 0x00ff00;
      object.texture = "wall";
    } else if (object.type === "hair") {
      object.lineColor = 0xff0000;
      object.lineWidth = 2;
    } else if (object.type === "tail") {
      object.textureTint = 0x00ffff;
      object.texture = "solid";
      object.lineDash = [5];
    } else if (object.type === "head") {
      object.texture = "diamond";
    }
  });

  viewer.scene.addModel(model1);
  viewer.scene.addModel(model2);
  viewer.camera.fitView([-90, 5, 130, 150]);
}

// async function getBase64Image(src, width = 64, height = width) {
//   const canvas = document.createElement("canvas");
//   canvas.width = width;
//   canvas.height = height;
//   var ctx = canvas.getContext("2d");
//   const image = new Image(width, height);
//   document.body.appendChild(image);
//   const promise = new Promise(res => (image.onload = res));
//   image.src = src;
//   await promise;
//   ctx.drawImage(image, 0, 0);
//   return canvas.toDataURL();
// }
